Chunk

Struct Chunk 

pub struct Chunk(/* private fields */);
Uncompressed chunk-data.

Implementations

Source

impl Chunk

pub const HYPERVOLUME: usize = 65_536usize

The hypervolume of a chunk.

pub const LENGTH: usize = 8usize

The size of a chunk along the Z axis,

pub const WIDTH: usize = 8usize

The size of a chunk along the X axis.

pub const WETH: usize = 8usize

The size of a chunk along the W axis.

pub const fn filled_with(block_id: u8) -> Self

Creates a new Chunk filled entirely with a block of the specified ID.

pub fn compress(&self) -> CompressedChunk<'_>

pub fn fill_with_params(&mut self, fill_params: FillParams<'_>)

Fills the specified area from point a to point b with a block of the specified ID.

pub fn fill(&mut self, block_id: u8, rect: Rect4)