pub struct Chunk(/* private fields */);Expand description
Uncompressed chunk-data.
Implementations
Sourceimpl Chunk
impl Chunk
Sourcepub const HYPERVOLUME: usize = 65_536usize
pub const HYPERVOLUME: usize = 65_536usize
The hypervolume of a chunk.
Sourcepub const fn filled_with(block_id: u8) -> Self
pub const fn filled_with(block_id: u8) -> Self
Creates a new Chunk filled entirely with a block of the specified ID.
pub fn compress(&self) -> CompressedChunk<'_>
Sourcepub fn fill_with_params(&mut self, fill_params: FillParams<'_>)
pub fn fill_with_params(&mut self, fill_params: FillParams<'_>)
Fills the specified area from point a to point b with a block of the specified ID.
pub fn fill(&mut self, block_id: u8, rect: Rect4)