Block

Enum Block 

#[non_exhaustive]
#[repr(u8)]
pub enum Block {
Show 34 variants Air = 0, Grass = 1, Dirt = 2, Stone = 3, Wood = 4, Leaf = 5, Lava = 6, IronOre = 7, DeadlyOre = 8, Chest = 9, MidnightGrass = 10, MidnightSoil = 11, MidnightStone = 12, MidnightWood = 13, MidnightLeaf = 14, Bush = 15, MidnightBush = 16, RedFlower = 17, WhiteFlower = 18, BlueFlower = 19, TallGrass = 20, Sand = 21, Sandstone = 22, Cactus = 23, Snow = 24, Ice = 25, SnowyBush = 26, Glass = 27, SolenoidOre = 28, SnowyLeaf = 29, Pumpkin = 30, JackOLantern = 31, Barrier = 32, ChunkBorder = 33,
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Air = 0

Air.



Grass = 1

Grass – a generic block of soil with green grass on top, used as the floor for most of the world.



Dirt = 2

Dirt – a generic block of soil which can be found under Grass.



Stone = 3

Stone – a generic block of (cobbled) stone which can be found under Dirt.



Wood = 4

Wood – a generic block to be used as a tree-trunk in non-Midnight biomes.



Leaf = 5



Lava = 6

Lava – a (purely decorative) placeholder block found at the bottom of the world.



IronOre = 7



DeadlyOre = 8

Deadly Ore – a glowing ore which produces the most valuable resource, Deadly Bars.



Chest = 9

Chest – a block that can store items.



MidnightGrass = 10

Midnight Grass – the Midnight biome’s variant of Block::Grass.



MidnightSoil = 11



MidnightStone = 12



MidnightWood = 13



MidnightLeaf = 14



Bush = 15



MidnightBush = 16



RedFlower = 17

A generic red flower.



WhiteFlower = 18

A generic white flower.



BlueFlower = 19

A generic blue flower.



TallGrass = 20



Sand = 21

Sand – a generic block of sand, used as the floor for the Desert biome.



Sandstone = 22

Sandstone – a generic block of (cobbled) sandstone which can be found under Sand.



Cactus = 23



Snow = 24



Ice = 25



SnowyBush = 26

Snowy Bush – the Snow biome’s variant of Block::Bush.



Glass = 27

Glass – a generic, see-through, block of glass crafted from Sand and Wood.



SolenoidOre = 28



SnowyLeaf = 29



Pumpkin = 30

Pumpkin – a naturally, but infrequently, occurring block in grasslands.



JackOLantern = 31



Barrier = 32

Barrier – a special block which, presumably, represents an impassible block



ChunkBorder = 33

A special block which represents the border of a chunk.

Implementations

Source

impl Block

pub const fn as_str(&self) -> &'static str